@@ -62,7 +62,7 @@ Before running this Airflow module...
 
 --------------------------------------------------------------
 
-Archive
+Storage Archive
 
 Wipe old information from a Storage bucket based on last update time.
 
@@ -139,8 +139,8 @@ RECIPE = {
   ]
 }
 
-DAG_FACTORY = DAG_Factory('archive', RECIPE, INPUTS)
-DAG = DAG_FACTORY.generate()
+dag_maker = DAG_Factory('archive', RECIPE, INPUTS)
+dag = dag_maker.generate()
 
 if __name__ == "__main__":
-  DAG_FACTORY.print_commandline()
+  dag_maker.print_commandline()
