@@ -67,8 +67,8 @@ DV360 User Audit
 Gives DV clients ability to see which users have access to which parts of an account. Loads DV user profile mappings using the API into BigQuery and connects to a DataStudio dashboard.
 
   - DV360 only permits SERVICE accounts to access the user list API endpoint, be sure to provide and permission one.
-  - Wait for <b>BigQuery->UNDEFINED->UNDEFINED->DV_*</b> to be created.
-  - Wait for <b>BigQuery->UNDEFINED->UNDEFINED->Barnacle_*</b> to be created, then copy and connect the following data sources.
+  - Wait for <b>BigQuery->->->DV_*</b> to be created.
+  - Wait for <b>BigQuery->->->Barnacle_*</b> to be created, then copy and connect the following data sources.
   - Join the <a hre='https://groups.google.com/d/forum/starthinker-assets' target='_blank'>StarThinker Assets Group</a> to access the following assets
   - Copy <a href='https://datastudio.google.com/c/u/0/reporting/9f6b9e62-43ec-4027-849a-287e9c1911bd' target='_blank'>Barnacle DV Report</a>.
   - Click Edit->Resource->Manage added data sources, then edit each connection to connect to your new tables above.
@@ -366,8 +366,8 @@ RECIPE = {
   ]
 }
 
-DAG_FACTORY = DAG_Factory('barnacle_dv360', RECIPE, INPUTS)
-DAG = DAG_FACTORY.generate()
+dag_maker = DAG_Factory('barnacle_dv360', RECIPE, INPUTS)
+dag = dag_maker.generate()
 
 if __name__ == "__main__":
-  DAG_FACTORY.print_commandline()
+  dag_maker.print_commandline()
