@@ -62,7 +62,7 @@ Before running this Airflow module...
 
 --------------------------------------------------------------
 
-Query to Sheet
+BigQuery Query to Sheet
 
 Copy the contents of a query into a Google Sheet.
 
@@ -168,8 +168,8 @@ RECIPE = {
   ]
 }
 
-DAG_FACTORY = DAG_Factory('bigquery_to_sheet', RECIPE, INPUTS)
-DAG = DAG_FACTORY.generate()
+dag_maker = DAG_Factory('bigquery_to_sheet', RECIPE, INPUTS)
+dag = dag_maker.generate()
 
 if __name__ == "__main__":
-  DAG_FACTORY.print_commandline()
+  dag_maker.print_commandline()
