@@ -62,7 +62,7 @@ Before running this Airflow module...
 
 --------------------------------------------------------------
 
-Conversion Upload BigQuery
+CM360 Conversion Upload From BigQuery
 
 Move from BigQuery to CM.
 
@@ -207,8 +207,8 @@ RECIPE = {
   ]
 }
 
-DAG_FACTORY = DAG_Factory('conversion_upload_from_biguery', RECIPE, INPUTS)
-DAG = DAG_FACTORY.generate()
+dag_maker = DAG_Factory('conversion_upload_from_biguery', RECIPE, INPUTS)
+dag = dag_maker.generate()
 
 if __name__ == "__main__":
-  DAG_FACTORY.print_commandline()
+  dag_maker.print_commandline()
