@@ -62,7 +62,7 @@ Before running this Airflow module...
 
 --------------------------------------------------------------
 
-DV360 To BigQuery
+DV360 Report To BigQuery
 
 Move existing DV360 reports into a BigQuery table.
 
@@ -178,8 +178,8 @@ RECIPE = {
   ]
 }
 
-DAG_FACTORY = DAG_Factory('dbm_to_bigquery', RECIPE, INPUTS)
-DAG = DAG_FACTORY.generate()
+dag_maker = DAG_Factory('dbm_to_bigquery', RECIPE, INPUTS)
+dag = dag_maker.generate()
 
 if __name__ == "__main__":
-  DAG_FACTORY.print_commandline()
+  dag_maker.print_commandline()
