@@ -62,7 +62,7 @@ Before running this Airflow module...
 
 --------------------------------------------------------------
 
-DV360 To Storage
+DV360 Report To Storage
 
 Move existing DV360 report into a Storage bucket.
 
@@ -157,8 +157,8 @@ RECIPE = {
   ]
 }
 
-DAG_FACTORY = DAG_Factory('dbm_to_storage', RECIPE, INPUTS)
-DAG = DAG_FACTORY.generate()
+dag_maker = DAG_Factory('dbm_to_storage', RECIPE, INPUTS)
+dag = dag_maker.generate()
 
 if __name__ == "__main__":
-  DAG_FACTORY.print_commandline()
+  dag_maker.print_commandline()
