@@ -62,12 +62,12 @@ Before running this Airflow module...
 
 --------------------------------------------------------------
 
-CM Log Audit
+CM360 Log Audit
 
 Downloads Campaign manager logs and allows audits.
 
-  - Wait for <b>BigQuery->UNDEFINED->UNDEFINED->CM_*</b> to be created.
-  - Wait for <b>BigQuery->UNDEFINED->UNDEFINED->Barnacle_*</b> to be created, then copy and connect the following data sources.
+  - Wait for <b>BigQuery->->->CM_*</b> to be created.
+  - Wait for <b>BigQuery->->->Barnacle_*</b> to be created, then copy and connect the following data sources.
   - Join the <a hre='https://groups.google.com/d/forum/starthinker-assets' target='_blank'>StarThinker Assets Group</a> to access the following assets
   - Copy <a href='https://datastudio.google.com/open/1a6K-XdPUzCYRXZp1ZcmeOUOURc9wn2Jj' target='_blank'>Barnacle Profile Advertiser Map</a> and connect.
   - Copy <a href='https://datastudio.google.com/open/1NEzrQWWnPjkD90iUwN-ASKbVBzoeBdoT' target='_blank'>Barnacle Profile Campaign Map</a> and connect.
@@ -215,8 +215,8 @@ RECIPE = {
   ]
 }
 
-DAG_FACTORY = DAG_Factory('dcm_log', RECIPE, INPUTS)
-DAG = DAG_FACTORY.generate()
+dag_maker = DAG_Factory('dcm_log', RECIPE, INPUTS)
+dag = dag_maker.generate()
 
 if __name__ == "__main__":
-  DAG_FACTORY.print_commandline()
+  dag_maker.print_commandline()
