@@ -62,14 +62,14 @@ Before running this Airflow module...
 
 --------------------------------------------------------------
 
-CM Report Replicate
+CM360 Report Replicate
 
 Replicate a report across multiple networks and advertisers.
 
   - Provide the name or ID of an existing report.
-  - Run the recipe once to generate the input sheet called CM Replicate For UNDEFINED.
+  - Run the recipe once to generate the input sheet called .
   - Enter network and advertiser ids to replicate the report.
-  - Data will be written to BigQuery &gt; UNDEFINED &gt; UNDEFINED &gt; [REPORT NAME]_All
+  - Data will be written to BigQuery &gt;  &gt;  &gt; _All
 
 --------------------------------------------------------------
 
@@ -103,7 +103,6 @@ RECIPE = {
           'destination': {
             'field': {
               'name': 'recipe_name',
-              'prefix': 'CM Replicate For ',
               'kind': 'string',
               'order': 1,
               'description': 'Name of document to deploy to.',
@@ -188,7 +187,6 @@ RECIPE = {
           'sheet': {
             'field': {
               'name': 'recipe_name',
-              'prefix': 'CM Replicate For ',
               'kind': 'string',
               'order': 1,
               'default': '',
@@ -223,8 +221,8 @@ RECIPE = {
   ]
 }
 
-DAG_FACTORY = DAG_Factory('dcm_replicate_to_bigquery', RECIPE, INPUTS)
-DAG = DAG_FACTORY.generate()
+dag_maker = DAG_Factory('dcm_replicate_to_bigquery', RECIPE, INPUTS)
+dag = dag_maker.generate()
 
 if __name__ == "__main__":
-  DAG_FACTORY.print_commandline()
+  dag_maker.print_commandline()
