@@ -62,7 +62,7 @@ Before running this Airflow module...
 
 --------------------------------------------------------------
 
-CM Report Run
+CM360 Report Run
 
 Trigger a CM report run
 
@@ -134,8 +134,8 @@ RECIPE = {
   ]
 }
 
-DAG_FACTORY = DAG_Factory('dcm_run', RECIPE, INPUTS)
-DAG = DAG_FACTORY.generate()
+dag_maker = DAG_Factory('dcm_run', RECIPE, INPUTS)
+dag = dag_maker.generate()
 
 if __name__ == "__main__":
-  DAG_FACTORY.print_commandline()
+  dag_maker.print_commandline()
