@@ -62,7 +62,7 @@ Before running this Airflow module...
 
 --------------------------------------------------------------
 
-CM To BigQuery
+CM360 Report To BigQuery
 
 Move existing CM report into a BigQuery table.
 
@@ -180,8 +180,8 @@ RECIPE = {
   ]
 }
 
-DAG_FACTORY = DAG_Factory('dcm_to_bigquery', RECIPE, INPUTS)
-DAG = DAG_FACTORY.generate()
+dag_maker = DAG_Factory('dcm_to_bigquery', RECIPE, INPUTS)
+dag = dag_maker.generate()
 
 if __name__ == "__main__":
-  DAG_FACTORY.print_commandline()
+  dag_maker.print_commandline()
