@@ -62,12 +62,12 @@ Before running this Airflow module...
 
 --------------------------------------------------------------
 
-CM Report Emailed To BigQuery
+CM360 Report Emailed To BigQuery
 
 Pulls a CM Report from a gMail powered email account into BigQuery.
 
   - The person executing this recipe must be the recipient of the email.
-  - Schedule a CM report to be sent to <b>UNDEFINED</b>.
+  - Schedule a CM report to be sent to <b></b>.
   - Or set up a redirect rule to forward a report you already receive.
   - The report must be sent as an attachment.
   - Ensure this recipe runs after the report is email daily.
@@ -165,8 +165,8 @@ RECIPE = {
   ]
 }
 
-DAG_FACTORY = DAG_Factory('email_cm_to_bigquery', RECIPE, INPUTS)
-DAG = DAG_FACTORY.generate()
+dag_maker = DAG_Factory('email_cm_to_bigquery', RECIPE, INPUTS)
+dag = dag_maker.generate()
 
 if __name__ == "__main__":
-  DAG_FACTORY.print_commandline()
+  dag_maker.print_commandline()
