@@ -67,7 +67,7 @@ DV360 Report Emailed To BigQuery
 Pulls a DV360 Report from a gMail email into BigQuery.
 
   - The person executing this recipe must be the recipient of the email.
-  - Schedule a DV360 report to be sent to an email like <b>UNDEFINED</b>.
+  - Schedule a DV360 report to be sent to an email like <b></b>.
   - Or set up a redirect rule to forward a report you already receive.
   - The report can be sent as an attachment or a link.
   - Ensure this recipe runs after the report is email daily.
@@ -176,8 +176,8 @@ RECIPE = {
   ]
 }
 
-DAG_FACTORY = DAG_Factory('email_dv360_to_bigquery', RECIPE, INPUTS)
-DAG = DAG_FACTORY.generate()
+dag_maker = DAG_Factory('email_dv360_to_bigquery', RECIPE, INPUTS)
+dag = dag_maker.generate()
 
 if __name__ == "__main__":
-  DAG_FACTORY.print_commandline()
+  dag_maker.print_commandline()
