@@ -158,8 +158,8 @@ RECIPE = {
   ]
 }
 
-DAG_FACTORY = DAG_Factory('lineitem_read_to_bigquery_via_query', RECIPE, INPUTS)
-DAG = DAG_FACTORY.generate()
+dag_maker = DAG_Factory('lineitem_read_to_bigquery_via_query', RECIPE, INPUTS)
+dag = dag_maker.generate()
 
 if __name__ == "__main__":
-  DAG_FACTORY.print_commandline()
+  dag_maker.print_commandline()
