@@ -62,7 +62,7 @@ Before running this Airflow module...
 
 --------------------------------------------------------------
 
-SDF Download
+DV360 SDF To BigQuery
 
 Download SDF reports into a BigQuery table.
 
@@ -224,8 +224,8 @@ RECIPE = {
   ]
 }
 
-DAG_FACTORY = DAG_Factory('sdf_to_bigquery', RECIPE, INPUTS)
-DAG = DAG_FACTORY.generate()
+dag_maker = DAG_Factory('sdf_to_bigquery', RECIPE, INPUTS)
+dag = dag_maker.generate()
 
 if __name__ == "__main__":
-  DAG_FACTORY.print_commandline()
+  dag_maker.print_commandline()
