@@ -62,14 +62,14 @@ Before running this Airflow module...
 
 --------------------------------------------------------------
 
-Segmentology DV360
+DV360 Segmentology
 
 DV360 funnel analysis using Census data.
 
-  - Wait for <b>BigQuery->UNDEFINED->UNDEFINED->Census_Join</b> to be created.
+  - Wait for <b>BigQuery->->->Census_Join</b> to be created.
   - Join the <a hre='https://groups.google.com/d/forum/starthinker-assets' target='_blank'>StarThinker Assets Group</a> to access the following assets
-  - Copy <a href='https://datastudio.google.com/c/u/0/reporting/4a908845-fdba-4023-9bb7-68666202bafb/page/K15YB/' target='_blank'>DV360 Segmentology</a>. Leave the Data Source as is, you will change it in the next step.
-  - Click Edit Connection, and change to <b>BigQuery->UNDEFINED->(field:recipe_slug}->Census_Join</b>.
+  - Copy <a href='https://datastudio.google.com/c/u/0/reporting/3673497b-f36f-4448-8fb9-3e05ea51842f/' target='_blank'>DV360 Segmentology Sample</a>. Leave the Data Source as is, you will change it in the next step.
+  - Click Edit Connection, and change to <b>BigQuery->->->Census_Join</b>.
   - Or give these intructions to the client.
 
 --------------------------------------------------------------
@@ -130,7 +130,7 @@ RECIPE = {
             'description': 'Credentials used for writing function.'
           }
         },
-        'function': 'pearson_significance_test',
+        'function': 'Pearson Significance Test',
         'to': {
           'dataset': {
             'field': {
@@ -317,7 +317,7 @@ RECIPE = {
               },
               {
                 'name': 'Clicks',
-                'type': 'INTEGER',
+                'type': 'FLOAT',
                 'mode': 'NULLABLE'
               },
               {
@@ -461,8 +461,8 @@ RECIPE = {
   ]
 }
 
-DAG_FACTORY = DAG_Factory('segmentology_dv360', RECIPE, INPUTS)
-DAG = DAG_FACTORY.generate()
+dag_maker = DAG_Factory('segmentology_dv360', RECIPE, INPUTS)
+dag = dag_maker.generate()
 
 if __name__ == "__main__":
-  DAG_FACTORY.print_commandline()
+  dag_maker.print_commandline()
