@@ -159,8 +159,8 @@ RECIPE = {
   ]
 }
 
-DAG_FACTORY = DAG_Factory('trends_places_to_bigquery_via_value', RECIPE, INPUTS)
-DAG = DAG_FACTORY.generate()
+dag_maker = DAG_Factory('trends_places_to_bigquery_via_value', RECIPE, INPUTS)
+dag = dag_maker.generate()
 
 if __name__ == "__main__":
-  DAG_FACTORY.print_commandline()
+  dag_maker.print_commandline()
