@@ -26,7 +26,6 @@ from starthinker.util.project import project
 from starthinker.util.regexp import lookup_id
 from starthinker.util.sheets import sheets_clear
 
-from starthinker.task.dv_editor.patch import patch_clear
 from starthinker.task.dv_editor.patch import patch_log
 from starthinker.task.dv_editor.patch import patch_masks
 from starthinker.task.dv_editor.patch import patch_preview
@@ -94,6 +93,7 @@ def line_item_load():
         CONCAT(L.displayName, ' - ', L.lineItemId),
         'PATCH',
         L.entityStatus,
+        L.entityStatus,
         ARRAY_TO_STRING(L.warningMessages, '\\n'),
 
         L.lineItemType,
@@ -132,7 +132,7 @@ def line_item_load():
         LEFT JOIN `{dataset}.DV_Advertisers` AS A
         ON L.advertiserId=A.advertiserId
         LEFT JOIN `{dataset}.DV_Campaigns` AS C
-        ON L.advertiserId=C.advertiserId
+        ON L.campaignId=C.campaignId
         LEFT JOIN `{dataset}.DV_InsertionOrders` AS I
         ON L.insertionOrderId=I.insertionOrderId
         LEFT JOIN `{dataset}.DV_Partners` AS P
@@ -177,6 +177,7 @@ def line_item_audit():
         { "name": "Line_Item", "type": "STRING" },
         { "name": "Action", "type": "STRING" },
         { "name": "Status", "type": "STRING" },
+        { "name": "Status_Edit", "type": "STRING" },
         { "name": "Warning", "type": "STRING" },
         { "name": "Line_Item_Type", "type": "STRING" },
         { "name": "Line_Item_Type_Edit", "type": "STRING" },
@@ -490,11 +491,10 @@ def line_item_patch(commit=False):
         })
 
   patch_masks(patches)
+  patch_preview(patches)
 
   if commit:
     line_item_commit(patches)
-  else:
-    patch_preview(patches)
 
 
 def line_item_insert(commit=False):
@@ -523,10 +523,10 @@ def line_item_insert(commit=False):
       }
     })
 
+  patch_preview(inserts)
+
   if commit:
     line_item_commit(inserts)
-  else:
-    patch_preview(inserts)
 
 
 def line_item_commit(patches):
@@ -556,6 +556,13 @@ def line_item_commit(patches):
           **patch["parameters"]
         ).execute()
         patch["success"] = response["lineItemId"]
+      elif patch["action"] == "TARGETING":
+        response = API_DV360(
+          project.task["auth_dv"]
+        ).advertisers().lineItems().bulkEditAdvertiserAssignedTargetingOptions(
+          **patch["parameters"]
+        ).execute()
+        patch["success"] = len(response["createdAssignedTargetingOptions"])
     except Exception as e:
       patch["error"] = str(e)
     finally:
