@@ -360,6 +360,10 @@ class PlacementDAO(BaseDAO):
       result['compatibility'] = 'IN_STREAM_VIDEO'
       result['size'] = {'width': '0', 'height': '0'}
       result['tagFormats'] = ['PLACEMENT_TAG_INSTREAM_VIDEO_PREFETCH']
+    elif feed_item[FieldMap.PLACEMENT_TYPE] == 'IN_STREAM_AUDIO':
+       result['compatibility'] = 'IN_STREAM_AUDIO'
+       result['size'] = {'width': '0', 'height': '0'}
+       result['tagFormats'] = ['PLACEMENT_TAG_INSTREAM_VIDEO_PREFETCH']
     else:
       result['compatibility'] = 'DISPLAY'
       width = 1
