@@ -352,12 +352,6 @@ def rows_to_table(auth,
       quoting=csv.QUOTE_MINIMAL)
   has_rows = False
 
-  if rows == []:
-    if project.verbose:
-      print('BigQuery Zero Rows')
-    return io_to_table(auth, project_id, dataset_id, table_id, buffer_data,
-                       'CSV', schema, skip_rows, disposition, wait)
-
   for is_last, row in flag_last(rows):
 
     # write row to csv buffer
@@ -381,8 +375,6 @@ def rows_to_table(auth,
 
   # if no rows, clear table to simulate empty write
   if not has_rows:
-    if project.verbose:
-      print('BigQuery Zero Rows')
     return io_to_table(auth, project_id, dataset_id, table_id, buffer_data,
                        'CSV', schema, skip_rows, disposition, wait)
 
@@ -428,8 +420,6 @@ def json_to_table(auth,
 
   # if no rows, clear table to simulate empty write
   if not has_rows:
-    if project.verbose:
-      print('BigQuery Zero Rows')
     return io_to_table(auth, project_id, dataset_id, table_id, buffer_data,
                        'NEWLINE_DELIMITED_JSON', schema, 0, disposition, wait)
 
@@ -798,6 +788,30 @@ def query_to_rows(auth,
       break
 
 
+def query_to_schema(auth, project_id, dataset_id, query, legacy=True):
+
+  if project.verbose:
+    print('BIGQUERY QUERY SCHEMA:', project_id, dataset_id)
+
+  body = {
+    'kind': 'bigquery#queryRequest',
+    'query': query,
+    'timeoutMs': 10000,
+    'dryRun': True,
+    'useLegacySql': legacy
+  }
+
+  if dataset_id:
+    body['defaultDataset'] = {'projectId': project_id, 'datasetId': dataset_id}
+
+  response = API_BigQuery(auth).jobs().query(
+    projectId=project_id,
+    body=body
+  ).execute()
+
+  return response['schema'].get('fields', [])
+
+
 def make_schema(header):
   return [{
       'name': name,
