@@ -23,9 +23,11 @@ from datetime import date, datetime
 
 RE_LOOKUP = re.compile(r' - (\d+)$')
 def lookup_id(lookup):
-  result = RE_LOOKUP.search(lookup)
-  return result.group(1) if result else None
-
+  if lookup:
+    result = RE_LOOKUP.search(lookup)
+    return result.group(1) if result else lookup
+  else:
+    return None
 
 def date_to_str(value):
   if value is None:
