@@ -13,6 +13,9 @@ class Command(BaseCommand):
 
   def handle(self, *args, **kwargs):
 
+    # hard code to be the internal server
+    settings.CONST_URL = "https://starthinker.corp.google.com"
+
     scripts = list(Script.get_scripts())
 
     print('Writing:', '%s/docs/GTECH' % settings.UI_ROOT)
